""" Contains create fooof action handling.
"""
import os 

from meggie.utilities.names import next_available_name

from meggie.utilities.messaging import exc_messagebox

from meggie.mainwindow.dynamic import Action
from meggie.mainwindow.dynamic import subject_action

from meggie_fooof.actions.fooof_create.dialogs.createReportDialogMain import CreateReportDialog
from meggie_fooof.actions.fooof_create.controller.fooof import create_report


class CreateFooof(Action):
    """ Creates FOOOF from existing spectrum.
    """

    def run(self):

        subject = self.experiment.active_subject

        try:
            selected_name = self.data['inputs']['spectrum'][0]
        except Exception as exc:
            return

        default_name = next_available_name(subject.fooof_report.keys(), selected_name)

        def handle_subject(subject, params):
            params['spectrum_name'] = selected_name
            self.handler(subject, params)

        dialog = CreateReportDialog(self.experiment, self.window, selected_name,
                                    default_name, handler=handle_subject)
        dialog.show()


    @subject_action
    def handler(self, subject, params):
        """
        """
        create_report(subject, params, do_meanwhile=self.window.update_ui)




# coding: utf-8

import logging
import os

import matplotlib.pyplot as plt

from meggie.utilities.filemanager import create_timestamped_folder
from meggie.utilities.filemanager import save_csv
from meggie.utilities.formats import format_float


def save_all_channels(experiment, selected_name):
    """ Saves peak params and aperiodic params to a csv file for every 
    subject and channel and condition """
    row_descs = []
    csv_data = []

    column_names = ['CF', 'Amp', 'BW', 
                    'Aperiodic offset', 'Aperiodic exponent']

    for subject in experiment.subjects.values():
        fooof_item = subject.fooof_report.get(selected_name)
        if not fooof_item:
            continue
        for key, report in fooof_item.content.items():
            for ch_idx, ch_name in enumerate(fooof_item.params['ch_names']):
                ch_report = report.get_fooof(ch_idx)
                for peak in ch_report.peak_params_:
                    csv_data.append([format_float(peak[0]),
                                     format_float(peak[1]),
                                     format_float(peak[2]), 
                                     '', ''])
                    row_descs.append((subject.name, key, ch_name))
                aparams = ch_report.aperiodic_params_
                csv_data.append(['', '', '',
                                 format_float(aparams[0]),
                                 format_float(aparams[1])])

                row_descs.append((subject.name, key, ch_name))

    # Save the resulting csv into a output folder 'meggie way'
    folder = create_timestamped_folder(experiment)
    fname = selected_name + '_all_subject_all_channels_fooof.csv'
    path = os.path.join(folder, fname)

    save_csv(path, csv_data, column_names, row_descs)
    logging.getLogger('ui_logger').info('Saved the csv file to ' + path)




# coding: utf-8

import logging

from PyQt5 import QtWidgets

from fooof import FOOOFGroup
from fooof.core.strings import gen_results_fg_str

from meggie_fooof.actions.fooof_create.dialogs.createReportDialogUi import Ui_CreateReportDialog

from meggie_fooof.datatypes.fooof_report.fooof_report import FOOOFReport

from meggie.utilities.widgets.batchingWidgetMain import BatchingWidget

from meggie.utilities.threading import threaded
from meggie.utilities.validators import validate_name
from meggie.utilities.messaging import exc_messagebox
from meggie.utilities.messaging import messagebox


class CreateReportDialog(QtWidgets.QDialog):
    """ Implements functionalities for widgets defined in the corresponding UI-file.
    """

    def __init__(self, experiment, parent, selected_spectrum, default_name, handler):
        """
        """
        QtWidgets.QDialog.__init__(self, parent)
        self.ui = Ui_CreateReportDialog()
        self.ui.setupUi(self)

        self.parent = parent
        self.experiment = experiment
        self.handler = handler
        self.selected_spectrum = selected_spectrum

        # initialize frequency limits from spectrum data
        spectrum_item = experiment.active_subject.spectrum[selected_spectrum]
        minfreq = spectrum_item.freqs[0]
        maxfreq = spectrum_item.freqs[-1]
        self.ui.doubleSpinBoxFreqMin.setValue(minfreq)
        self.ui.doubleSpinBoxFreqMax.setValue(maxfreq)

        # add a general batching widget to dialog
        self.batching_widget = BatchingWidget(
            experiment_getter=self.experiment_getter,
            parent=self,
            container=self.ui.groupBoxBatching,
            geometry=self.ui.batchingWidgetPlaceholder.geometry())
        self.ui.gridLayoutBatching.addWidget(self.batching_widget, 0, 0, 1, 1)

        self.ui.lineEditName.setText(default_name)

    def experiment_getter(self):
        return self.experiment

    def create_report(self, subject, selected_spectrum):
        """ Collect parameters from the dialog and creates an FOOOFReport item
        """

        report_name = validate_name(self.ui.lineEditName.text())

        spectrum = subject.spectrum.get(selected_spectrum)

        peak_width_low = self.ui.doubleSpinBoxPeakWidthLow.value()
        peak_width_high = self.ui.doubleSpinBoxPeakWidthHigh.value()
        peak_threshold = self.ui.doubleSpinBoxPeakThreshold.value()
        max_n_peaks = self.ui.spinBoxMaxNPeaks.value()
        aperiodic_mode = self.ui.comboBoxAperiodicMode.currentText()
        minfreq = self.ui.doubleSpinBoxFreqMin.value()
        maxfreq = self.ui.doubleSpinBoxFreqMax.value()

        peak_width_limits = [peak_width_low, peak_width_high]
        peak_threshold = peak_threshold
        max_n_peaks = max_n_peaks
        aperiodic_mode = aperiodic_mode
        freq_range = [minfreq, maxfreq]

        # As meggie spectrum items can contain data for multiple conditions,
        # reports are also created for all those conditions, and dict is used.
        report_content = {}

        for key, data in spectrum.content.items():

            fg = FOOOFGroup(peak_width_limits=peak_width_limits,
			    peak_threshold=peak_threshold,
			    max_n_peaks=max_n_peaks,
                            aperiodic_mode=aperiodic_mode,
			    verbose=False)

            @threaded
            def fit(**kwargs):
                """ Run fitting in a separate thread so that UI stays responsive
                """
                fg.fit(spectrum.freqs, data, freq_range)

            fit(do_meanwhile=self.parent.update_ui)

            logging.getLogger('ui_logger').info('FOOOF results for ' +
                                                subject.name + ', ' +
                                                'condition: ' + key)
            # Log the textual report
            logging.getLogger('ui_logger').info(
                gen_results_fg_str(fg, concise=True))

            report_content[key] = fg

        params = {
            'conditions': list(spectrum.content.keys()),
            'based_on': selected_spectrum,
            'ch_names': spectrum.ch_names,
        }

        fooof_directory = subject.fooof_report_directory

        # Create a container item that meggie understands, 
        # and which holds the report data
        report = FOOOFReport(report_name, 
                             fooof_directory,
                             params,
                             report_content)

        # save report data to fs
        report.save_content()

        # and add the report item to subject
        subject.add(report, 'fooof_report')

    def accept(self):
        """ Start item creation for current subject
        """
        subject = self.experiment.active_subject
        selected_spectrum = self.selected_spectrum

        params = {}
        try:
            params['name'] = validate_name(self.ui.lineEditName.text())
        except Exception as exc:
            exc_messagebox(self, exc)
            return

        params['peak_width_low'] = self.ui.doubleSpinBoxPeakWidthLow.value()
        params['peak_width_high'] = self.ui.doubleSpinBoxPeakWidthHigh.value()
        params['peak_threshold'] = self.ui.doubleSpinBoxPeakThreshold.value()
        params['max_n_peaks'] = self.ui.spinBoxMaxNPeaks.value()
        params['aperiodic_mode'] = self.ui.comboBoxAperiodicMode.currentText()
        params['minfreq'] = self.ui.doubleSpinBoxFreqMin.value()
        params['maxfreq'] = self.ui.doubleSpinBoxFreqMax.value()

        try:
            self.handler(subject, params)
            self.experiment.save_experiment_settings()
        except Exception as exc:
            exc_messagebox(self, exc)
            return

        # Update experiment file and the window
        self.parent.initialize_ui()

        self.close()

    def acceptBatch(self):
        """ Start item creation of all subjects selected in the batching widget
        """
        selected_spectrum = self.selected_spectrum
        experiment = self.experiment

        params = {}
        try:
            params['name'] = validate_name(self.ui.lineEditName.text())
        except Exception as exc:
            exc_messagebox(self, exc)
            return

        params['peak_width_low'] = self.ui.doubleSpinBoxPeakWidthLow.value()
        params['peak_width_high'] = self.ui.doubleSpinBoxPeakWidthHigh.value()
        params['peak_threshold'] = self.ui.doubleSpinBoxPeakThreshold.value()
        params['max_n_peaks'] = self.ui.spinBoxMaxNPeaks.value()
        params['aperiodic_mode'] = self.ui.comboBoxAperiodicMode.currentText()
        params['minfreq'] = self.ui.doubleSpinBoxFreqMin.value()
        params['maxfreq'] = self.ui.doubleSpinBoxFreqMax.value()

        selected_subject_names = self.batching_widget.selected_subjects

        # Loop through every subject creating items and collecting info from
        # failed cases
        for name, subject in self.experiment.subjects.items():
            if name in selected_subject_names:
                try:
                    self.handler(subject, params)
                    subject.release_memory()
                except Exception as exc:
                    self.batching_widget.failed_subjects.append(
                        (subject, str(exc)))
                    logging.getLogger('ui_logger').exception(str(exc))

        # if any fails, tell user about them
        self.batching_widget.cleanup()

        # and update experiment file and the UI
        try:
            self.experiment.save_experiment_settings()
        except Exception as exc:
            exc_messagebox(self.parent, exc)

        self.parent.initialize_ui()

        self.close()



# coding: utf-8

import matplotlib.pyplot as plt

from meggie.utilities.formats import format_float
from meggie.utilities.formats import format_floats
from meggie.utilities.plotting import color_cycle
from meggie.utilities.channels import iterate_topography


def plot_topo_fit(subject, report_item):
    """ Plot topography where by clicking subplots you can check the fit parameters
    of specific channels """

    reports = report_item.content
    ch_names = report_item.params['ch_names']
    freqs = list(reports.values())[0].freqs

    colors = color_cycle(len(reports))

    raw = subject.get_raw()
    info = raw.info

    def on_pick(ax, info_idx, names_idx):
        """ When a subplot representing a specific channel is clicked on the 
        main topography plot, show a new figure containing FOOOF fit plot
        for every condition """

        fig = ax.figure
        fig.delaxes(ax)

        for idx, (report_key, report) in enumerate(reports.items()):
            report_ax = fig.add_subplot(1, len(reports), idx+1)
            fooof = report.get_fooof(names_idx)

            # Use plot function from fooof
            fooof.plot(
                ax=report_ax,
                plot_peaks='dot',
                add_legend=False,
            )
            # Add information about the fit to the axis title
            text = ("Condition: " + str(report_key) + "\n" +
                    "R squred: " + format_float(fooof.r_squared_) + "\n" +
                    "Peaks: \n")
            for peak_params in fooof.peak_params_:
                text = text + '{0} ({1}, {2})\n'.format(*format_floats(peak_params))

            report_ax.set_title(text)

        fig.tight_layout()

    # Create a topography where one can inspect fits by clicking subplots
    fig = plt.figure()
    for ax, info_idx, names_idx in iterate_topography(
            fig, info, ch_names, on_pick):

        handles = []
        for color_idx, (key, report) in enumerate(reports.items()):
            curve = report.power_spectra[names_idx]
            handles.append(
                ax.plot(curve, color=colors[color_idx],
                        linewidth=0.5, label=key)[0])

    fig.legend(handles=handles)
    fig.canvas.set_window_title(report_item.name)
    fig.suptitle(report_item.name)

    plt.show()




""" Contains functions for handling FOOOFs
"""

import logging

from PyQt5 import QtWidgets

from fooof import FOOOFGroup
from fooof.core.strings import gen_results_fg_str

from meggie_fooof.actions.fooof_create.dialogs.createReportDialogUi import Ui_CreateReportDialog

from meggie_fooof.datatypes.fooof_report.fooof_report import FOOOFReport

from meggie.utilities.widgets.batchingWidgetMain import BatchingWidget

from meggie.utilities.threading import threaded
from meggie.utilities.validators import validate_name
from meggie.utilities.messaging import exc_messagebox
from meggie.utilities.messaging import messagebox


@threaded
def create_report(subject, params):
    """ Collect parameters from the dialog and creates an FOOOFReport item
    """

    report_name = params['name']
    spectrum_name = params['spectrum_name']

    peak_width_low = params['peak_width_low']
    peak_width_high = params['peak_width_high']
    peak_threshold = params['peak_threshold']
    max_n_peaks = params['max_n_peaks']
    aperiodic_mode = params['aperiodic_mode']
    minfreq = params['minfreq']
    maxfreq = params['maxfreq']

    spectrum = subject.spectrum.get(spectrum_name)

    peak_width_limits = [peak_width_low, peak_width_high]
    peak_threshold = peak_threshold
    max_n_peaks = max_n_peaks
    aperiodic_mode = aperiodic_mode
    freq_range = [minfreq, maxfreq]

    # As meggie spectrum items can contain data for multiple conditions,
    # reports are also created for all those conditions, and dict is used.
    report_content = {}

    for key, data in spectrum.content.items():

        fg = FOOOFGroup(peak_width_limits=peak_width_limits,
            peak_threshold=peak_threshold,
            max_n_peaks=max_n_peaks,
                        aperiodic_mode=aperiodic_mode,
            verbose=False)

        fg.fit(spectrum.freqs, data, freq_range)

        logging.getLogger('ui_logger').info('FOOOF results for ' +
                                            subject.name + ', ' +
                                            'condition: ' + key)
        # Log the textual report
        logging.getLogger('ui_logger').info(
            gen_results_fg_str(fg, concise=True))

        report_content[key] = fg

    params['conditions'] = list(spectrum.content.keys())
    params['ch_names'] = spectrum.ch_names

    fooof_directory = subject.fooof_report_directory

    # Create a container item that meggie understands, 
    # and which holds the report data
    report = FOOOFReport(report_name, 
                         fooof_directory,
                         params,
                         report_content)

    # save report data to fs
    report.save_content()

    # and add the report item to subject
    subject.add(report, 'fooof_report')



from setuptools import setup

setup(
    name='meggie_fooof',
    version='0.2.0',
    description="",
    author='CIBR',
    author_email='erkka.heinila@jyu.fi',
    url='https://github.com/Teekuningas/meggie_fooof',
    license='BSD',
    packages=['meggie_fooof'],
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        'setuptools',
        'meggie>=1.3.0',
        'fooof'
    ]
)



""" Contains implementation for fooof info
"""
import os

from meggie.mainwindow.dynamic import InfoAction


class Info(InfoAction):
    """ Fills up fooof info box """

    def run(self):

        message = ""
        try:
            selected_name = self.data['outputs']['fooof_report'][0]
            fooof_item = self.experiment.active_subject.fooof_report[selected_name]
            params = fooof_item.params

            message += "Name: {0}\n\n".format(fooof_item.name)

            if 'spectrum_name' in params:
                message += "Based on: {0}\n".format(params['spectrum_name'])

        except Exception as exc:
            message = ""
        return message




"""
"""

import os
import re
import logging

from fooof import FOOOFGroup


class FOOOFReport(object):
    """ Container for FOOOF report data that can be handled by meggie
    """

    def __init__(self, name, fooof_directory, params, content=None):
        """
        """
        self._name = name
        self._content = {}

        # on item creation, content is passed and is set here
        if content is not None:
            self._content = content
        
        self._path = fooof_directory
        self._params = params

    @property
    def content(self):
        """ Return report data if already in memory, otherwise read from fs. 
        Content is assumed to be a dictionary with conditions as keys 
        and reports as values """
        if self._content:
            return self._content

        template = self.name + '_' + r'([a-zA-Z1-9_]+)\.json'
        for fname in os.listdir(self._path):
            match = re.match(template, fname)
            if match:
                try:
                    key = str(match.group(1))
                except Exception as exc:
                    raise Exception("Unknown file name format.")

                if 'conditions' in self._params:
                    if key not in [str(elem) for elem 
                                   in self._params['conditions']]:
                        continue

                logging.getLogger('ui_logger').debug(
                        'Reading FOOOF file: ' + str(fname))

                fg = FOOOFGroup()
                fg.load(fname, self._path)
                self._content[key] = fg
        return self._content

    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, name):
        self._name = name

    @property
    def params(self):
        return self._params

    @params.setter
    def params(self, params):
        self._params = params

    def save_content(self):
        """ Save dictionary containing reports to fs
        """
        try:
            # if exists, delete first
            self.delete_content()

            for key, report in self._content.items():
                fname = self._name + '_' + str(key) + '.json'
                report.save(fname, self._path, save_results=True, 
                            save_settings=True, save_data=True)

        except Exception as exc:
            raise IOError('Writing FOOOF report failed')

    def delete_content(self):
        """ Delete report data from the fs
        """
        template = self.name + '_' + r'([a-zA-Z1-9_]+)\.json'
        for fname in os.listdir(self._path):
            match = re.match(template, fname)
            if match:
                try:
                    key = str(match.group(1))
                except Exception as exc:
                    continue

                if 'conditions' in self._params:
                    if key not in [str(elem) for elem 
                                   in self._params['conditions']]:
                        continue

                logging.getLogger('ui_logger').debug(
                        'Removing existing fooof file: ' + str(fname))

                os.remove(os.path.join(self._path, fname))




""" Contains implementation for fooof plot
"""
import logging

import matplotlib.pyplot as plt
import numpy as np

from meggie.utilities.messaging import exc_messagebox

from meggie.mainwindow.dynamic import Action
from meggie.mainwindow.dynamic import subject_action

from meggie_fooof.actions.fooof_save.controller.fooof import save_all_channels


class SaveFooof(Action):
    """ Saves FOOOF to a csv.
    """

    def run(self):

        try:
            selected_name = self.data['outputs']['fooof_report'][0]
        except IndexError as exc:
            return

        subject = self.experiment.active_subject

        try:
            self.handler(subject, {'name': selected_name})
        except Exception as exc:
            exc_messagebox(self.window, exc)


    @subject_action
    def handler(self, subject, params):
        save_all_channels(self.experiment, params['name'])
        



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'designer_ui_files/createReportDialogUi.ui'
#
# Created by: PyQt5 UI code generator 5.9.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_CreateReportDialog(object):
    def setupUi(self, CreateReportDialog):
        CreateReportDialog.setObjectName("CreateReportDialog")
        CreateReportDialog.resize(386, 530)
        self.gridLayout = QtWidgets.QGridLayout(CreateReportDialog)
        self.gridLayout.setObjectName("gridLayout")
        self.horizontalLayoutButtons = QtWidgets.QHBoxLayout()
        self.horizontalLayoutButtons.setObjectName("horizontalLayoutButtons")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayoutButtons.addItem(spacerItem)
        self.pushButtonCancel = QtWidgets.QPushButton(CreateReportDialog)
        self.pushButtonCancel.setObjectName("pushButtonCancel")
        self.horizontalLayoutButtons.addWidget(self.pushButtonCancel)
        self.pushButtonBatch = QtWidgets.QPushButton(CreateReportDialog)
        self.pushButtonBatch.setObjectName("pushButtonBatch")
        self.horizontalLayoutButtons.addWidget(self.pushButtonBatch)
        self.pushButtonApply = QtWidgets.QPushButton(CreateReportDialog)
        self.pushButtonApply.setObjectName("pushButtonApply")
        self.horizontalLayoutButtons.addWidget(self.pushButtonApply)
        self.gridLayout.addLayout(self.horizontalLayoutButtons, 2, 0, 1, 1)
        self.scrollArea = QtWidgets.QScrollArea(CreateReportDialog)
        self.scrollArea.setWidgetResizable(True)
        self.scrollArea.setObjectName("scrollArea")
        self.scrollAreaWidgetContents = QtWidgets.QWidget()
        self.scrollAreaWidgetContents.setGeometry(QtCore.QRect(0, 0, 352, 700))
        self.scrollAreaWidgetContents.setObjectName("scrollAreaWidgetContents")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.scrollAreaWidgetContents)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.groupBoxBatching = QtWidgets.QGroupBox(self.scrollAreaWidgetContents)
        self.groupBoxBatching.setObjectName("groupBoxBatching")
        self.gridLayoutBatching = QtWidgets.QGridLayout(self.groupBoxBatching)
        self.gridLayoutBatching.setContentsMargins(9, 9, 9, 9)
        self.gridLayoutBatching.setObjectName("gridLayoutBatching")
        self.batchingWidgetPlaceholder = QtWidgets.QWidget(self.groupBoxBatching)
        self.batchingWidgetPlaceholder.setMinimumSize(QtCore.QSize(300, 300))
        self.batchingWidgetPlaceholder.setObjectName("batchingWidgetPlaceholder")
        self.gridLayoutBatching.addWidget(self.batchingWidgetPlaceholder, 0, 0, 1, 1)
        self.gridLayout_2.addWidget(self.groupBoxBatching, 2, 0, 1, 1)
        self.groupBoxInfo = QtWidgets.QGroupBox(self.scrollAreaWidgetContents)
        self.groupBoxInfo.setObjectName("groupBoxInfo")
        self.formLayout = QtWidgets.QFormLayout(self.groupBoxInfo)
        self.formLayout.setObjectName("formLayout")
        self.labelName = QtWidgets.QLabel(self.groupBoxInfo)
        self.labelName.setObjectName("labelName")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.labelName)
        self.lineEditName = QtWidgets.QLineEdit(self.groupBoxInfo)
        self.lineEditName.setObjectName("lineEditName")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.lineEditName)
        self.gridLayout_2.addWidget(self.groupBoxInfo, 0, 0, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_2.addItem(spacerItem1, 3, 0, 1, 1)
        self.groupBoxParameters = QtWidgets.QGroupBox(self.scrollAreaWidgetContents)
        self.groupBoxParameters.setObjectName("groupBoxParameters")
        self.formLayout_2 = QtWidgets.QFormLayout(self.groupBoxParameters)
        self.formLayout_2.setObjectName("formLayout_2")
        self.labelPeakWidthLow = QtWidgets.QLabel(self.groupBoxParameters)
        self.labelPeakWidthLow.setObjectName("labelPeakWidthLow")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.labelPeakWidthLow)
        self.doubleSpinBoxPeakWidthLow = QtWidgets.QDoubleSpinBox(self.groupBoxParameters)
        self.doubleSpinBoxPeakWidthLow.setMinimum(0.5)
        self.doubleSpinBoxPeakWidthLow.setMaximum(999.99)
        self.doubleSpinBoxPeakWidthLow.setSingleStep(0.1)
        self.doubleSpinBoxPeakWidthLow.setObjectName("doubleSpinBoxPeakWidthLow")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.doubleSpinBoxPeakWidthLow)
        self.labelPeakWidthHigh = QtWidgets.QLabel(self.groupBoxParameters)
        self.labelPeakWidthHigh.setObjectName("labelPeakWidthHigh")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.labelPeakWidthHigh)
        self.doubleSpinBoxPeakWidthHigh = QtWidgets.QDoubleSpinBox(self.groupBoxParameters)
        self.doubleSpinBoxPeakWidthHigh.setMaximum(999.99)
        self.doubleSpinBoxPeakWidthHigh.setSingleStep(0.1)
        self.doubleSpinBoxPeakWidthHigh.setProperty("value", 12.0)
        self.doubleSpinBoxPeakWidthHigh.setObjectName("doubleSpinBoxPeakWidthHigh")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.doubleSpinBoxPeakWidthHigh)
        self.labelPeakThreshold = QtWidgets.QLabel(self.groupBoxParameters)
        self.labelPeakThreshold.setObjectName("labelPeakThreshold")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.labelPeakThreshold)
        self.doubleSpinBoxPeakThreshold = QtWidgets.QDoubleSpinBox(self.groupBoxParameters)
        self.doubleSpinBoxPeakThreshold.setMaximum(9999.99)
        self.doubleSpinBoxPeakThreshold.setSingleStep(0.1)
        self.doubleSpinBoxPeakThreshold.setProperty("value", 2.0)
        self.doubleSpinBoxPeakThreshold.setObjectName("doubleSpinBoxPeakThreshold")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.doubleSpinBoxPeakThreshold)
        self.labelFreqMin = QtWidgets.QLabel(self.groupBoxParameters)
        self.labelFreqMin.setObjectName("labelFreqMin")
        self.formLayout_2.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.labelFreqMin)
        self.doubleSpinBoxFreqMin = QtWidgets.QDoubleSpinBox(self.groupBoxParameters)
        self.doubleSpinBoxFreqMin.setMaximum(999.99)
        self.doubleSpinBoxFreqMin.setObjectName("doubleSpinBoxFreqMin")
        self.formLayout_2.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.doubleSpinBoxFreqMin)
        self.labelFreqMax = QtWidgets.QLabel(self.groupBoxParameters)
        self.labelFreqMax.setObjectName("labelFreqMax")
        self.formLayout_2.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.labelFreqMax)
        self.doubleSpinBoxFreqMax = QtWidgets.QDoubleSpinBox(self.groupBoxParameters)
        self.doubleSpinBoxFreqMax.setMaximum(999.99)
        self.doubleSpinBoxFreqMax.setProperty("value", 30.0)
        self.doubleSpinBoxFreqMax.setObjectName("doubleSpinBoxFreqMax")
        self.formLayout_2.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.doubleSpinBoxFreqMax)
        self.labelMaxNPeaks = QtWidgets.QLabel(self.groupBoxParameters)
        self.labelMaxNPeaks.setObjectName("labelMaxNPeaks")
        self.formLayout_2.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.labelMaxNPeaks)
        self.spinBoxMaxNPeaks = QtWidgets.QSpinBox(self.groupBoxParameters)
        self.spinBoxMaxNPeaks.setProperty("value", 6)
        self.spinBoxMaxNPeaks.setObjectName("spinBoxMaxNPeaks")
        self.formLayout_2.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.spinBoxMaxNPeaks)
        self.labelAperiodicMode = QtWidgets.QLabel(self.groupBoxParameters)
        self.labelAperiodicMode.setObjectName("labelAperiodicMode")
        self.formLayout_2.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.labelAperiodicMode)
        self.comboBoxAperiodicMode = QtWidgets.QComboBox(self.groupBoxParameters)
        self.comboBoxAperiodicMode.setObjectName("comboBoxAperiodicMode")
        self.comboBoxAperiodicMode.addItem("")
        self.comboBoxAperiodicMode.addItem("")
        self.formLayout_2.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.comboBoxAperiodicMode)
        self.gridLayout_2.addWidget(self.groupBoxParameters, 1, 0, 1, 1)
        self.scrollArea.setWidget(self.scrollAreaWidgetContents)
        self.gridLayout.addWidget(self.scrollArea, 0, 0, 1, 1)

        self.retranslateUi(CreateReportDialog)
        self.pushButtonCancel.clicked.connect(CreateReportDialog.close)
        self.pushButtonApply.clicked.connect(CreateReportDialog.accept)
        self.pushButtonBatch.clicked.connect(CreateReportDialog.acceptBatch)
        QtCore.QMetaObject.connectSlotsByName(CreateReportDialog)
        CreateReportDialog.setTabOrder(self.scrollArea, self.lineEditName)
        CreateReportDialog.setTabOrder(self.lineEditName, self.doubleSpinBoxPeakWidthLow)
        CreateReportDialog.setTabOrder(self.doubleSpinBoxPeakWidthLow, self.doubleSpinBoxPeakWidthHigh)
        CreateReportDialog.setTabOrder(self.doubleSpinBoxPeakWidthHigh, self.doubleSpinBoxPeakThreshold)
        CreateReportDialog.setTabOrder(self.doubleSpinBoxPeakThreshold, self.doubleSpinBoxFreqMin)
        CreateReportDialog.setTabOrder(self.doubleSpinBoxFreqMin, self.doubleSpinBoxFreqMax)
        CreateReportDialog.setTabOrder(self.doubleSpinBoxFreqMax, self.spinBoxMaxNPeaks)
        CreateReportDialog.setTabOrder(self.spinBoxMaxNPeaks, self.comboBoxAperiodicMode)
        CreateReportDialog.setTabOrder(self.comboBoxAperiodicMode, self.pushButtonCancel)
        CreateReportDialog.setTabOrder(self.pushButtonCancel, self.pushButtonBatch)
        CreateReportDialog.setTabOrder(self.pushButtonBatch, self.pushButtonApply)

    def retranslateUi(self, CreateReportDialog):
        _translate = QtCore.QCoreApplication.translate
        CreateReportDialog.setWindowTitle(_translate("CreateReportDialog", "Meggie - Create report"))
        self.pushButtonCancel.setText(_translate("CreateReportDialog", "Cancel"))
        self.pushButtonBatch.setText(_translate("CreateReportDialog", "Batch"))
        self.pushButtonApply.setText(_translate("CreateReportDialog", "Apply"))
        self.groupBoxBatching.setTitle(_translate("CreateReportDialog", "Batching"))
        self.groupBoxInfo.setTitle(_translate("CreateReportDialog", "Info"))
        self.labelName.setText(_translate("CreateReportDialog", "Name:"))
        self.groupBoxParameters.setTitle(_translate("CreateReportDialog", "Parameters"))
        self.labelPeakWidthLow.setText(_translate("CreateReportDialog", "Peak width low:"))
        self.doubleSpinBoxPeakWidthLow.setSuffix(_translate("CreateReportDialog", "Hz"))
        self.labelPeakWidthHigh.setText(_translate("CreateReportDialog", "Peak width high:"))
        self.doubleSpinBoxPeakWidthHigh.setSuffix(_translate("CreateReportDialog", "Hz"))
        self.labelPeakThreshold.setText(_translate("CreateReportDialog", "Peak threshold (relative):"))
        self.labelFreqMin.setText(_translate("CreateReportDialog", "Min frequency:"))
        self.labelFreqMax.setText(_translate("CreateReportDialog", "Max frequency:"))
        self.labelMaxNPeaks.setText(_translate("CreateReportDialog", "Max number of peaks:"))
        self.labelAperiodicMode.setText(_translate("CreateReportDialog", "Aperiodic mode:"))
        self.comboBoxAperiodicMode.setItemText(0, _translate("CreateReportDialog", "fixed"))
        self.comboBoxAperiodicMode.setItemText(1, _translate("CreateReportDialog", "knee"))

